@@ -15,7 +15,7 @@ from flask.ext.flatpages import FlatPages
 from flask.ext.pagedown import PageDown
 from flask.ext.login import LoginManager
 from flask.ext.babel import Babel
-from flask.ext.themes2 import Themes, load_themes_from
+from flask.ext.themes2 import Themes
 
 # create app
 app = Flask(__name__)
@@ -53,17 +53,7 @@ lm.login_view = 'admin.login'
 babel = Babel(app)
 
 # themes support
-def load_themes(app) :
-    """
-    Themes loader
-    """
-    path = op.join(op.dirname(__file__), 'themes')
-    if op.isdir(path) :
-        return load_themes_from(path)
-    else :
-        return ()
-
-Themes(app, app_identifier = 'microbe', loaders = [load_themes])
+Themes(app, app_identifier = 'microbe')
 
 # blueprint
 from admin import bp as admin_module
